==> u61-0.2.2.tar.gz: u61-0.2.2/src/gameoptionmenu.cpp <==
/****************************************************************************
 *                                                                          *
 * U U    6   1            U U   FFF  O   O  TTT                            *
 * U U   6   11   b        U U   F   O O O O  T                             *
 * U U - 66   1   bb  y y  U U - FF  O O O O  T                             *
 * U U   6 6  1   b b  y   U U   F   O O O O  T                             *
 *  U     6   1   bb   y    U    F    O   O   T                             *
 *                                                                          *
 * U61 is another block based game                                          *
 * Copyright (C) 2000 Christian Mauduit (ufoot@ufoot.org / www.ufoot.org)   *
 *                                                                          *
 * This program is free software; you can redistribute it and/or            *
 * modify it under the terms of the GNU General Public License              *
 * as published by the Free Software Foundation; either version 2           *
 * of the License, or (at your option) any later version.                   *
 *                                                                          *
 * This program is distributed in the hope that it will be useful,          *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of           *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            *
 * GNU General Public License for more details.                             *
 *                                                                          *
 * You should have received a copy of the GNU General Public License        *
 * along with this program; if not, write to the Free Software              *
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA*
 *                                                                          *
 * This project is also available on SourceForge  (http://sourceforge.net)  *
 ****************************************************************************/

/*
 * file name:   gameoptionmenu.cpp
 * author:      U-Foot (ufoot@ufoot.org / www.ufoot.org)
 * description: this menu is the main option menu.
 *              its role is to guide the user to other submenus which
 *              will then allow the user to change its settings
 */


/*---------------------------------------------------------------------------
 includes
 ---------------------------------------------------------------------------*/

#include "gameoptionmenu.h"
#include "emptymenu.h"
#include "speedmenu.h"
#include "scriptfilemenu.h"
#include "datafilemenu.h"
#include "soundmenu.h"
#include "button.h"
#include "global.h"
#include "networkoptionmenu.h"

/*---------------------------------------------------------------------------
 globals
 ---------------------------------------------------------------------------*/


/*---------------------------------------------------------------------------
 functions
 ---------------------------------------------------------------------------*/

/*--------------------------------------------------------------------------*/
/* 
 * creation of the option menu
 */ 
U61_GameOptionMenu::U61_GameOptionMenu(U61_Menu *parent)
    : U61_Menu(parent,"Set up your options")
{
    add_item(new U61_Button("Speed"));
    add_item(new U61_Button("Network"));
    add_item(new U61_Button("Rules"));
    add_item(new U61_Button("Theme"));
    add_item(new U61_Button("Sound"));
    select(0);
}

/*--------------------------------------------------------------------------*/
/*
 * validate is called when the user presses enter
 */
U61_Menu *U61_GameOptionMenu::validate()
{
    U61_Menu *next_menu;

    next_menu=this;
    switch (selection)
    {
    case 0:
        next_menu=new U61_SpeedMenu(this, &(U61_Global::config));
        break;
    case 1:
        next_menu=new U61_NetworkOptionMenu(this, &(U61_Global::config));
        break;
    case 2:
        next_menu=new U61_ScriptFileMenu(this, &(U61_Global::config));
        break;
    case 3:
        next_menu=new U61_DataFileMenu(this, &(U61_Global::config));
        break;
    case 4:
        next_menu=new U61_SoundMenu(this, &(U61_Global::config));
        break;
    }

    return next_menu;
}

==> u61-0.3.2.tar.gz: u61-0.3.2/src/gameoptionmenu.cpp <==
/****************************************************************************
 *                                                                          *
 * U U    6   1            U U   FFF  O   O  TTT                            *
 * U U   6   11   b        U U   F   O O O O  T                             *
 * U U - 66   1   bb  y y  U U - FF  O O O O  T                             *
 * U U   6 6  1   b b  y   U U   F   O O O O  T                             *
 *  U     6   1   bb   y    U    F    O   O   T                             *
 *                                                                          *
 * U61 is another block based game                                          *
 * Copyright (C) 2000 Christian Mauduit (ufoot@ufoot.org / www.ufoot.org)   *
 *                                                                          *
 * This program is free software; you can redistribute it and/or            *
 * modify it under the terms of the GNU General Public License              *
 * as published by the Free Software Foundation; either version 2           *
 * of the License, or (at your option) any later version.                   *
 *                                                                          *
 * This program is distributed in the hope that it will be useful,          *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of           *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            *
 * GNU General Public License for more details.                             *
 *                                                                          *
 * You should have received a copy of the GNU General Public License        *
 * along with this program; if not, write to the Free Software              *
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA*
 *                                                                          *
 * This project is also available on SourceForge  (http://sourceforge.net)  *
 ****************************************************************************/

/*
 * file name:   gameoptionmenu.cpp
 * author:      U-Foot (ufoot@ufoot.org / www.ufoot.org)
 * description: this menu is the main option menu.
 *              its role is to guide the user to other submenus which
 *              will then allow the user to change its settings
 */


/*---------------------------------------------------------------------------
 includes
 ---------------------------------------------------------------------------*/

#include "gameoptionmenu.h"
#include "emptymenu.h"
#include "speedmenu.h"
#include "scriptfilemenu.h"
#include "datafilemenu.h"
#include "soundmenu.h"
#include "button.h"
#include "global.h"
#include "networkoptionmenu.h"
#include "graphicsmenu.h"

/*---------------------------------------------------------------------------
 globals
 ---------------------------------------------------------------------------*/


/*---------------------------------------------------------------------------
 functions
 ---------------------------------------------------------------------------*/

/*--------------------------------------------------------------------------*/
/* 
 * creation of the option menu
 */ 
U61_GameOptionMenu::U61_GameOptionMenu(U61_Menu *parent)
  : U61_Menu(parent,"Set up your options")
{
  add_item(new U61_Button("Speed"));
  add_item(new U61_Button("Network"));
  add_item(new U61_Button("Rules"));
  add_item(new U61_Button("Theme"));
  add_item(new U61_Button("Graphics"));
  add_item(new U61_Button("Sound"));
  select(0);
}

/*--------------------------------------------------------------------------*/
/*
 * validate is called when the user presses enter
 */
U61_Menu *U61_GameOptionMenu::validate()
{
  U61_Menu *next_menu;

  next_menu=this;
  switch (selection)
    {
    case 0:
      next_menu=new U61_SpeedMenu(this, &(U61_Global::config));
      break;
    case 1:
      next_menu=new U61_NetworkOptionMenu(this, &(U61_Global::config));
      break;
    case 2:
      next_menu=new U61_ScriptFileMenu(this, &(U61_Global::config));
      break;
    case 3:
      next_menu=new U61_DataFileMenu(this, &(U61_Global::config)); 
      break;
    case 4:
      next_menu=new U61_GraphicsMenu(this, &(U61_Global::config));
      break;
    case 5:
      next_menu=new U61_SoundMenu(this, &(U61_Global::config));
      break;
    }

  return next_menu;
}
